@@ -17,20 +17,26 @@ namespace qamlib
 {
 class StreamingDevice : public Device {
     protected:
+	StreamingDevice(const std::string &device, v4l2_buf_type device_type,
+			uint32_t needed_cap)
+		: Device(device, device_type, needed_cap)
+	{
+	}
+
 	std::map<std::string, ImageFormat> formats;
 
-	std::atomic<bool> streaming;
+	std::atomic<bool> streaming = false;
 
 	// Used for all set/get of format and for knowing the currently used
 	// format is
-	struct v4l2_format current_format;
+	struct v4l2_format streaming_format;
 	PixelSize pix_size = BITS8;
 	bool big_endian = false;
 
 	/*
 	 * Private format helper functions
 	 */
-	void read_format();
+	struct v4l2_format read_format();
 
 	void update_format();
 
