@@ -18,26 +18,6 @@ nox.options.sessions = (
 )
 
 
-@session(name="pre-commit")
-def precommit(session: Session) -> None:
-    """Lint using pre-commit."""
-    args = session.posargs or ["run", "--all-files"]
-    session.install(
-        "black",
-        "darglint",
-        "flake8",
-        "flake8-bandit",
-        "flake8-bugbear",
-        "flake8-docstrings",
-        "flake8-rst-docstrings",
-        "pep8-naming",
-        "pre-commit",
-        "pre-commit-hooks",
-        "pyupgrade",
-        "reorder-python-imports",
-    )
-    session.run("pre-commit", *args)
-
 
 @session(name="build")
 def build(session: Session) -> None:
@@ -50,13 +30,12 @@ def build(session: Session) -> None:
 @session(name="docs-build")
 def docs_build(session: Session) -> None:
     """Build the documentation."""
-    args = session.posargs or ["docs", "docs/_build"]
+    args = session.posargs or ["-W", "--keep-going", "docs", "docs/_build"]
     if not session.posargs and "FORCE_COLOR" in os.environ:
         args.insert(0, "--color")
 
     session.install(
         "sphinx",
-        "sphinx-click",
         "breathe",
         "sphinx-autodoc-typehints",
         "furo",
