@@ -54,10 +54,6 @@ void Camera::start()
 
 	ready_buffers();
 
-	// Make sure that width and height are up to date when starting
-	// streaming
-	get_resolution();
-
 #if PYTHON
 	// Import NumPy now, so that it does not need to be done when creating
 	// the first NumPy array for a requested frame
@@ -179,7 +175,7 @@ std::tuple<FrameMetadata, cv::Mat> Camera::get_frame(uint32_t timeout,
 		// We use expected imagesize instead of bytesused,
 		// since Gstreamer (v4l2sink) seems to not set the
 		// correct bytesused and instead sets it to buffersize.
-		current_format.fmt.pix.sizeimage,
+		streaming_format.fmt.pix.sizeimage,
 		static_cast<uint8_t *>(buffers[frame->index].start));
 
 	if (pix_size == BITS16) {
@@ -190,10 +186,10 @@ std::tuple<FrameMetadata, cv::Mat> Camera::get_frame(uint32_t timeout,
 		}
 	}
 #else
-	int height = static_cast<int>(current_format.fmt.pix.height);
-	int width = static_cast<int>(current_format.fmt.pix.width);
+	int height = static_cast<int>(streaming_format.fmt.pix.height);
+	int width = static_cast<int>(streaming_format.fmt.pix.width);
 
-	uint32_t size = current_format.fmt.pix.sizeimage;
+	uint32_t size = streaming_format.fmt.pix.sizeimage;
 
 	int32_t type;
 	if (pix_size == BITS16) {
@@ -226,8 +222,8 @@ std::tuple<FrameMetadata, cv::Mat> Camera::get_frame(uint32_t timeout,
 
 // Currently only reshape for Python
 #ifdef PYTHON
-	int height = static_cast<int>(current_format.fmt.pix.height);
-	int width = static_cast<int>(current_format.fmt.pix.width);
+	int height = static_cast<int>(streaming_format.fmt.pix.height);
+	int width = static_cast<int>(streaming_format.fmt.pix.width);
 
 	// TODO for some formats we might not want to shape the array
 	// Using -1 as the last dimension will let it autosize
@@ -243,7 +239,7 @@ std::tuple<FrameMetadata, cv::Mat> Camera::get_frame(uint32_t timeout,
  */
 std::unique_ptr<Format> Camera::get_format()
 {
-	read_format();
+	auto current_format = read_format();
 
 	return std::unique_ptr<Format>(new SinglePlaneFormat(
 		&current_format.fmt.pix, V4L2_BUF_TYPE_VIDEO_CAPTURE));
@@ -251,6 +247,8 @@ std::unique_ptr<Format> Camera::get_format()
 
 std::unique_ptr<Format> Camera::set_format(Format &format)
 {
+	auto current_format = read_format();
+
 	if (format.type == V4L2_BUF_TYPE_VIDEO_CAPTURE) {
 		auto tmp = static_cast<SinglePlaneFormat &>(format);
 
@@ -289,10 +287,12 @@ std::unique_ptr<Format> Camera::set_format(Format &format)
 
 std::unique_ptr<Format> Camera::set_format(std::string &name, bool big_endian)
 {
+	auto current_format = read_format();
 	if (big_endian) {
 		name += "_BE";
 	}
 
+	update_formats();
 	auto it = formats.find(name);
 
 	if (it == formats.end()) {
@@ -336,7 +336,7 @@ std::unique_ptr<Format> Camera::set_format(std::string &name, bool big_endian)
  */
 std::unique_ptr<FrameRate> Camera::get_framerates()
 {
-	read_format();
+	auto current_format = read_format();
 
 	return enum_framerates(current_format.fmt.pix.pixelformat,
 			       current_format.fmt.pix.width,
@@ -346,7 +346,7 @@ std::unique_ptr<FrameRate> Camera::get_framerates()
 std::unique_ptr<FrameRate> Camera::get_framerates(uint32_t width,
 						  uint32_t height)
 {
-	read_format();
+	auto current_format = read_format();
 
 	return enum_framerates(current_format.fmt.pix.pixelformat, width,
 			       height);
