@@ -54,6 +54,8 @@ template <typename T> class VectorIterator {
 };
 
 /* Device */
+char device_info_docs[] = ":py:class:`DeviceInfo` object";
+
 char get_control_docs0[] =
 	"Get current value of control by name\n\n"
 	"This is only for non-extended controls (eg. integer, menu, etc.)\n\n"
@@ -338,7 +340,6 @@ PYBIND11_MODULE(qamlib, m)
 		.value("FWHT_PARAMS",
 		       v4l2_ctrl_type::V4L2_CTRL_TYPE_FWHT_PARAMS)
 		.value("VP8_FRAME", v4l2_ctrl_type::V4L2_CTRL_TYPE_VP8_FRAME)
-		.value("VP8_FRAME", v4l2_ctrl_type::V4L2_CTRL_TYPE_VP8_FRAME)
 #endif
 #if LINUX_VERSION_CODE >= KERNEL_VERSION(5, 5, 0)
 		.value("AREA", v4l2_ctrl_type::V4L2_CTRL_TYPE_AREA)
@@ -481,7 +482,6 @@ PYBIND11_MODULE(qamlib, m)
 		.def("to_json", &ArrayControlValue::to_json)
 		.def("__repr__", &ArrayControlValue::to_string)
 		.def("__str__", &ArrayControlValue::to_string);
-#ifdef QTEC_HEADER
 	py::class_<trigger_sequence>(m, "trigger_sequence",
 				     "V4L2 struct for a sequence")
 		.def_readwrite("exposure_time",
@@ -496,8 +496,9 @@ PYBIND11_MODULE(qamlib, m)
 	py::class_<TriggerSequenceValue, ControlValue>(
 		m, "TriggerSequenceValue",
 		"Class that represents the values of a trigger sequence\n\n"
-		"NOTE: The trigger sequence control is not implemented for all "
-		"Qtec cameras and/or sensors configurations.")
+		"NOTE: Qtec specific control at the moment. The trigger "
+		"sequence control is not implemented for all Qtec cameras "
+		"and/or sensors configurations.")
 		.def(py::init())
 		.def_property_readonly("value",
 				       &TriggerSequenceValue::get_sequence,
@@ -505,24 +506,12 @@ PYBIND11_MODULE(qamlib, m)
 		.def("clear", &TriggerSequenceValue::clear,
 		     "Clear the sequences")
 		.def("add_exposure", &TriggerSequenceValue::add_exposure,
+		     py::arg("exposure_time"), py::arg("flash_time"),
+		     py::arg("frame_delay"), py::arg("trigger_delay"),
 		     "Add an exposure to the sequence")
-		.def(
-			"add_sequence",
-			[](TriggerSequenceValue &self, uint32_t exposure_time,
-			   uint32_t flash_time, uint32_t frame_delay,
-			   uint32_t trigger_delay) {
-				std::cerr
-					<< "add_sequence is deprecated please use "
-					   "add_exposure instead"
-					<< std::endl;
-				self.add_exposure(exposure_time, flash_time,
-						  frame_delay, trigger_delay);
-			},
-			"Add an exposure to the sequence. DEPRECATED")
 		.def("to_json", &TriggerSequenceValue::to_json)
 		.def("__repr__", &TriggerSequenceValue::to_string)
 		.def("__str__", &TriggerSequenceValue::to_string);
-#endif
 
 	/*
 	 * MISC
@@ -701,10 +690,21 @@ PYBIND11_MODULE(qamlib, m)
 			},
 			py::keep_alive<0, 1>());
 
+	py::class_<DeviceInfo>(
+		m, "DeviceInfo",
+		"Class containing information about the video device")
+		.def_readonly("driver", &DeviceInfo::driver, "String")
+		.def_readonly("card", &DeviceInfo::card, "String")
+		.def_readonly("bus_info", &DeviceInfo::bus_info, "String")
+		.def("__repr__", &DeviceInfo::to_string)
+		.def("__str__", &DeviceInfo::to_string);
+
 	/*
 	 * Device classes
 	 */
 	py::class_<Device>(m, "Device", "Base class for a V4L2 device")
+		.def_readonly("device_info", &Device::device_info,
+			      device_info_docs)
 		.def("get_control",
 		     py::overload_cast<const std::string &>(
 			     &Device::get_control),
@@ -846,7 +846,17 @@ PYBIND11_MODULE(qamlib, m)
 		.value("MOTION_DET", EventType::MOTION_DET);
 
 	py::class_<BaseEvent>(m, "BaseEvent", "Base class for Event types")
-		.def_readonly("type", &BaseEvent::type, "Type of the event");
+		.def_readonly("type", &BaseEvent::type, "Type of the event")
+		.def_readonly("pending", &BaseEvent::id,
+			      "Number of pending events")
+		.def_readonly("sequence", &BaseEvent::sequence,
+			      "Event sequence number")
+		.def_readonly("timestamp", &BaseEvent::timestamp,
+			      "Event timestamp")
+		.def_readonly(
+			"id", &BaseEvent::id,
+			"Control ID associated with the event source. If the event does not have an associated ID, this value is 0.");
+	;
 
 	py::class_<ControlChangesFlags>(
 		m, "ControlChangesFlags",
